( cd usr/bin ; rm -rf nm86 )
( cd usr/bin ; ln -sf objdump86 nm86 )
( cd usr/bin ; rm -rf size86 )
( cd usr/bin ; ln -sf objdump86 size86 )
( cd usr/man/man1 ; rm -rf as86_encap.1.gz )
( cd usr/man/man1 ; ln -sf as86.1.gz as86_encap.1.gz )
